$ifndef _INTERRUPT_MANAGER_
$define _INTERRUPT_MANAGER_

$if (_device <> _18F25K20) And (_device <> _18F25K22)
    $error "Interrupt manager is only for 18F25K20 or 18F25K22 devices"
$endif
'
' Proton high priority interrupt manager macros
' For use with version 3.5.3.3 onwards of the compiler and 18F25K20 or 18F25K22 devices.
'
' You are free to use this code as you see fit, however, a mention of the author and compiler would be appreciated.
' The code is offered as-is and Crownhill nor the author take any responsibility for its use.
'
' Written by Les Johnson 26-02-2012
'
' In order for all programs to see this file,
' Copy it into the compiler's Sources folder.
' Default Win XP or Win7 32-bit location: "C:\Program Files\ProtonIDE\PDS\Includes\Sources"
' Or Win7 64-bit:                         "C:\Program Files (x86)\ProtonIDE\PDS\Includes\Sources"     
'
$ifndef True
    $define True 1
$endif
$ifndef False
    $define False 0
$endif
'
' Handler defines available
'
(*
$define Handle_PORTB
$define Handle_INT0
$define Handle_INT1
$define Handle_INT2
$define Handle_RX
$define Handle_TX
$define Handle_SSP
$define Handle_RX1
$define Handle_TX1
$define Handle_SSP1
$define Handle_CCP1
$define Handle_CCP2
$define Handle_TMR0
$define Handle_TMR1
$define Handle_TMR2_Match
$define Handle_TMR3
$define Handle_ADC
$define Handle_OSC
$define Handle_COMP1
$define Handle_COMP2
$define Handle_FLASH
$define Handle_BUS
$define Handle_BUS1
$define Handle_VOLTS

$define Handle_RX2
$define Handle_TX2
$define Handle_SSP2
$define Handle_BUS2
$define Handle_TMR1_Gate
$define Handle_TMR3_Gate
$define Handle_TMR5_Gate
$define Handle_CTMU
$define Handle_CCP3
$define Handle_CCP4
$define Handle_CCP5

$define Handle_TMR6_Match
$define Handle_TMR4_Match
$define Handle_TMR5
*)
'
' Interrupt flag alias names
'
    $define IntFlag_TMR0 INTCONbits_TMR0IF
    $define IntFlag_TMR1 PIR1bits_TMR1IF
    $define IntFlag_TMR2_Match PIR1bits_TMR2IF
    $define IntFlag_TMR3 PIR2bits_TMR3IF
    $define IntFlag_INT0 INTCONbits_INT0IF
    $define IntFlag_INT1 INTCON3bits_INT1IF
    $define IntFlag_INT2 INTCON3bits_INT2IF
    $define IntFlag_PORTB INTCONbits_RBIF
    $define IntFlag_RX PIR1bits_RCIF
    $define IntFlag_TX PIR1bits_TXIF
    $define IntFlag_SSP PIR1bits_SSPIF
    $define IntFlag_RX1 PIR1bits_RCIF
    $define IntFlag_TX1 PIR1bits_TXIF
    $define IntFlag_SSP1 PIR1bits_SSPIF
    $define IntFlag_CCP1 PIR1bits_CCP1IF
    $define IntFlag_CCP2 PIR2bits_CCP2IF
    $define IntFlag_ADC PIR1bits_ADIF
    $define IntFlag_COMP1 PIR2bits_C1IF
    $define IntFlag_COMP2 PIR2bits_C2IF
    $define IntFlag_FLASH PIR2bits_EEIF
    $define IntFlag_BUS PIR2bits_BCLIF
    $define IntFlag_BUS1 PIR2bits_BCLIF
    $define IntFlag_VOLTS PIR2bits_HLVDIF
    $define IntFlag_OSC PIR2bits_OSCFIF
'
' Flags for the 18F25K22 device
'
$ifdef _Amicus18_Rev2
    $define IntFlag_SSP2 PIR3bits_SSP2IF
    $define IntFlag_BUS2 PIR3bits_BCL2IF
    $define IntFlag_RX2 PIR3bits_RC2IF
    $define IntFlag_TX2 PIR3bits_TX2IF
    $define IntFlag_CTMU PIR3bits_CTMUIF
    $define IntFlag_TMR5_Gate PIR3bits_TMR5GIF
    $define IntFlag_TMR3_Gate PIR3bits_TMR3GIF
    $define IntFlag_TMR1_Gate PIR3bits_TMR1GIF
    $define IntFlag_CCP5 PIR4bits_CCP5IF
    $define IntFlag_CCP4 PIR4bits_CCP4IF
    $define IntFlag_CCP3 PIR4bits_CCP3IF
    $define IntFlag_TMR6_Match PIR5bits_TMR6IF
    $define IntFlag_TMR5 PIR5bits_TMR5IF
    $define IntFlag_TMR4_Match PIR5bits_TMR4IF
$endif ' 18F25K22 device

'------------------------------------------------------------------
' Enable\Disable global interrupts
'
    $define Int_Global(pParam1) '
    $if pParam1 = Enable      '
        INTCONbits_GIE = 1    '
    $elseif pParam1 = Disable '
        INTCONbits_GIE = 0    '
    $else                     '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable peripheral interrupts
'
    $define Int_Peripheral(pParam1) '
    $if pParam1 = Enable      '
        INTCONbits_PEIE = 1   '
    $elseif pParam1 = Disable '
        INTCONbits_PEIE = 0   '
    $else                     '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the TMR0 overflow interrupt
'
    $define Int_TMR0(pParam1) '
    $if pParam1 = Enable      '
        INTCONbits_TMR0IE = 1 '
    $elseif pParam1 = Disable '
        INTCONbits_TMR0IE = 0 '
    $else                     '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the TMR1 overflow interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR1(pParam1)   '
    $if pParam1 = Enable        '
        PIE1bits_TMR1IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_TMR1IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the TMR2 to PR2 match interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR2_Match(pParam1)   '
    $if pParam1 = Enable        '
        PIE1bits_TMR2IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_TMR2IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the TMR3 overflow interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR3(pParam1)   '
    $if pParam1 = Enable        '
        PIE2bits_TMR3IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_TMR3IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the INT0 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_INT0(pParam1)   '
    $if pParam1 = Enable        '
        INTCONbits_INT0IE = 1   '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        INTCONbits_INT0IE = 0   '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the INT1 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_INT1(pParam1)   '
    $if pParam1 = Enable        '
        INTCON3bits_INT1IE = 1   '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        INTCON3bits_INT1IE = 0   '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the INT2 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_INT2(pParam1)   '
    $if pParam1 = Enable        '
        INTCON3bits_INT2IE = 1  '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        INTCON3bits_INT2IE = 0  '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the CCP1 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CCP1(pParam1)   '
    $if pParam1 = Enable        '
        PIE1bits_CCP1IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_CCP1IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the CCP2 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CCP2(pParam1)   '
    $if pParam1 = Enable        '
        PIE2bits_CCP2IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_CCP2IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the PORTB change interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_PORTB(pParam1)  '
    $if pParam1 = Enable        '
        INTCONbits_RBIE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        INTCONbits_RBIE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the ADC interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_ADC(pParam1)    '
    $if pParam1 = Enable        '
        PIE1bits_ADIE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_ADIE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the UART1 receive interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_RX(pParam1)     '
    $if pParam1 = Enable        '
        PIE1bits_RCIE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_RCIE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

$define Int_RX1(pParam1) Int_RX(pParam1)
'------------------------------------------------------------------
' Enable\Disable the UART1 transmit interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TX(pParam1)     '
    $if pParam1 = Enable        '
        PIE1bits_TXIE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_TXIE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

$define Int_TX1(pParam1) Int_TX(pParam1)
'------------------------------------------------------------------
' Enable\Disable the SSP1 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_SSP(pParam1)    '
    $if pParam1 = Enable        '
        PIE1bits_SSPIE = 1      '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE1bits_SSPIE = 0      '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

$define Int_SSP1(pParam1) Int_SSP(pParam1)
'------------------------------------------------------------------
' Enable\Disable the Oscillator Fail interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_OSC(pParam1)    '
    $if pParam1 = Enable        '
        PIE2bits_OSCFIE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_OSCFIE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the Comparitor 1 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_Comp1(pParam1)  '
    $if pParam1 = Enable        '
        PIE2bits_C1IE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_C1IE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the Comparitor 2 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_Comp2(pParam1)  '
    $if pParam1 = Enable        '
        PIE2bits_C2IE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_C2IE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the Eeprom and Flash Write interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_FLASH(pParam1)  '
    $if pParam1 = Enable        '
        PIE2bits_EEIE = 1       '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_EEIE = 0       '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the MSSP1 Bus collision interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_BUS(pParam1)    '
    $if pParam1 = Enable        '
        PIE2bits_BCLIE = 1      '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE2bits_BCLIE = 0      '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

$define Int_BUS1(pParam1) Int_BUS(pParam1)
'------------------------------------------------------------------
' Enable\Disable the Low Voltage interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_VOLTS(pParam1)        '
    $if pParam1 = Enable              '
        PIE2bits_HLVDIE = 1           '
        $ifndef _PEIE_REQ_            '
            $define _PEIE_REQ_        '
            INTCONbits_PEIE = 1       '
        $endif                        '
    $elseif pParam1 = Disable         '
        PIE2bits_HLVDIE = 0           '
    $else                             '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'
' For the 18F25K22 device
'
$if _device = _18F25K22
'------------------------------------------------------------------
' Enable\Disable the UART2 receive interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_RX2(pParam1)    '
    $if pParam1 = Enable        '
        PIE3bits_RC2IE = 1      '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_RC2IE = 0      '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the UART2 transmit interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TX2(pParam1)    '
    $if pParam1 = Enable        '
        PIE3bits_TX2IE = 1      '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_TX2IE = 0      '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
'------------------------------------------------------------------
' Enable\Disable the SSP2 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_SSP2(pParam1)    '
    $if pParam1 = Enable        '
        PIE3bits_SSP2IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_SSP2IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the MSSP2 Bus collision interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_BUS2(pParam1) '
    $if pParam1 = Enable        '
        PIE3bits_BCL2IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_BCL2IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer1 Gate interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR1_Gate(pParam1)   '
    $if pParam1 = Enable        '
        PIE3bits_TMR1GIE = 1    '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_TMR1GIE = 0    '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer3 Gate interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR3_Gate(pParam1) '
    $if pParam1 = Enable        '
        PIE3bits_TMR3GIE = 1    '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_TMR3GIE = 0    '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer5 Gate interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR5_Gate(pParam1) '
    $if pParam1 = Enable        '
        PIE3bits_TMR5GIE = 1    '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_TMR5GIE = 0    '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the CTMU (Charge Time Measurement Unit) interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CTMU(pParam1)   '
    $if pParam1 = Enable        '
        PIE3bits_CTMUIE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE3bits_CTMUIE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the CCP3 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CCP3(pParam1) '
    $if pParam1 = Enable        '
        PIE4bits_CCP3IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE4bits_CCP3IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the CCP4 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CCP4(pParam1) '
    $if pParam1 = Enable        '
        PIE4bits_CCP4IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE4bits_CCP4IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the CCP5 interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_CCP5(pParam1) '
    $if pParam1 = Enable        '
        PIE4bits_CCP5IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE4bits_CCP5IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer6 to PR6 match interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR6_Match(pParam1) '
    $if pParam1 = Enable        '
        PIE5bits_TMR6IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE5bits_TMR6IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer5 overflow interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR5(pParam1)   '
    $if pParam1 = Enable        '
        PIE5bits_TMR5IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE5bits_TMR5IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif

'------------------------------------------------------------------
' Enable\Disable the Timer4 to PR4 match interrupt
'
' Notes : Sets the peripheral interrupt flag, if not already set
'
    $define Int_TMR4_Match(pParam1) '
    $if pParam1 = Enable        '
        PIE5bits_TMR4IE = 1     '
        $ifndef _PEIE_REQ_      '
            $define _PEIE_REQ_  '
            INTCONbits_PEIE = 1 '
        $endif                  '
    $elseif pParam1 = Disable   '
        PIE5bits_TMR4IE = 0     '
    $else                       '
        $error "Unrecognised parameter. Enable or Disable only" '
    $endif
$endif ' 18F25K22 device

'------------------------------------------------------------------

    $define _Managed_ISR

'----------------------------------------------------------------------------
' The main high priority ISR handler subroutine
'
' This routine calls the relevant peripheral interrupt handlers
'
$if _defined(Handle_PORTB) Or _defined(Handle_INT0) Or _defined(Handle_INT1) Or _defined(Handle_INT2) Or _defined(Handle_RX) Or _defined(Handle_TX) '
 Or _defined(Handle_RX1) Or _defined(Handle_TX1) Or _defined(Handle_SSP1) Or _defined(Handle_SSP) Or _defined(Handle_CCP1) Or _defined(Handle_CCP2) '
 Or _defined(Handle_TMR0) Or _defined(Handle_TMR1) Or _defined(Handle_TMR2_Match) Or _defined(Handle_TMR3) Or _defined(Handle_ADC) Or _defined(Handle_OSC) '
 Or _defined(Handle_COMP1) Or _defined(Handle_COMP2) Or _defined(Handle_FLASH) Or _defined(Handle_BUS)  Or _defined(Handle_BUS1) '
 Or _defined(Handle_VOLTS) Or _defined(Handle_RX2) Or _defined(Handle_TX2) Or _defined(Handle_SSP2) Or _defined(Handle_BUS2) '
 Or _defined(Handle_TMR1_Gate) Or _defined(Handle_TMR3_Gate) Or _defined(Handle_TMR5_Gate) Or _defined(Handle_CTMU) Or _defined(Handle_CCP3) '
 Or _defined(Handle_CCP4) Or _defined(Handle_CCP5) Or _defined(Handle_TMR4_Match) Or _defined(Handle_TMR5) Or _defined(Handle_TMR6_Match)

Declare Reminders = Off
    On_Hardware_Interrupt GoTo _ISR_High
    GoTo InterruptManagerMain               ' Jump over the interrupt handler subroutine

_ISR_High:

$ifdef _Managed_ISR
    Context Save FSR0L, FSR0H, FSR1L, FSR1H
$endif

$if _defined(Handle_RX) Or _defined(Handle_RX1)
    If IntFlag_RX = 1 Then
        GoSub _ISR_RX
    EndIf
$endif

$if _defined(Handle_SSP) Or _defined(Handle_SSP1)
    If IntFlag_SSP = 1 Then
        GoSub _ISR_SSP
    EndIf
$endif

$ifdef Handle_TMR0
    If IntFlag_TMR0 = 1 Then
        GoSub _ISR_TMR0
    EndIf
$endif

$ifdef Handle_TMR1
    If IntFlag_TMR1 = 1 Then
        GoSub _ISR_TMR1
    EndIf
$endif

$ifdef Handle_TMR2_Match
    If IntFlag_TMR2_Match = 1 Then
        GoSub _ISR_TMR2_Match
    EndIf
$endif

$ifdef Handle_TMR3
    If IntFlag_TMR3 = 1 Then
        GoSub _ISR_TMR3
    EndIf
$endif

$ifdef Handle_INT0
    If IntFlag_INT0 = 1 Then
        GoSub _ISR_INT0
    EndIf
$endif

$ifdef Handle_INT1
    If IntFlag_INT1 = 1 Then
        GoSub _ISR_INT1
    EndIf
$endif

$ifdef Handle_INT2
    If IntFlag_INT2 = 1 Then
        GoSub _ISR_INT2
    EndIf
$endif

$ifdef Handle_PORTB
    If IntFlag_PORTB = 1 Then
        GoSub _ISR_RB
    EndIf
$endif

$if _defined(Handle_TX) Or _defined(Handle_TX1)
    If IntFlag_TX = 1 Then
        GoSub _ISR_TX
    EndIf
$endif

$ifdef Handle_CCP1
    If IntFlag_CCP1 = 1 Then
        GoSub _ISR_CCP1
    EndIf
$endif

$ifdef Handle_CCP2
    If IntFlag_CCP2 = 1 Then
        GoSub _ISR_CCP2
    EndIf
$endif

$ifdef Handle_ADC
    If IntFlag_ADC = 1 Then
        GoSub _ISR_ADC
    EndIf
$endif

$ifdef Handle_COMP1
    If IntFlag_COMP1= 1 Then
        GoSub _ISR_COMP1
    EndIf
$endif

$ifdef Handle_COMP2
    If IntFlag_COMP2 = 1 Then
        GoSub _ISR_COMP2
    EndIf
$endif

$ifdef Handle_FLASH
    If IntFlag_FLASH = 1 Then
        GoSub _ISR_FLASH
    EndIf
$endif

$if _defined(Handle_BUS) Or _defined(Handle_BUS1)
    If IntFlag_BUS = 1 Then
        GoSub _ISR_BUS
    EndIf
$endif

$ifdef Handle_VOLTS
    If IntFlag_VOLTS = 1 Then
        GoSub _ISR_Low_Voltage
    EndIf
$endif

$ifdef Handle_OSC
    If IntFlag_OSC = 1 Then
        GoSub _ISR_OSC
    EndIf
$endif
'
' For the 18F25K22 device
'
$if _device = _18F25K22

$ifdef Handle_RX2
    If IntFlag_RX2 = 1 Then
        GoSub _ISR_RX2
    EndIf
$endif

$ifdef Handle_TX2
    If IntFlag_TX2 = 1 Then
        GoSub _ISR_TX2
    EndIf
$endif

$ifdef Handle_SSP2
    If IntFlag_SSP2 = 1 Then
        GoSub _ISR_SSP2
    EndIf
$endif

$ifdef Handle_BUS2
    If IntFlag_BUS2 = 1 Then
        GoSub _ISR_BUS2
    EndIf
$endif

$ifdef Handle_TMR1_Gate
    If IntFlag_TMR1_Gate = 1 Then
        GoSub _ISR_TMR1_Gate
    EndIf
$endif

$ifdef Handle_TMR3_Gate
    If IntFlag_TMR3_Gate = 1 Then
        GoSub _ISR_TMR3_Gate
    EndIf
$endif

$ifdef Handle_TMR5_Gate
    If IntFlag_TMR5_Gate = 1 Then
        GoSub _ISR_TMR5_Gate
    EndIf
$endif

$ifdef Handle_CTMU
    If IntFlag_CTMU = 1 Then
        GoSub _ISR_CTMU
    EndIf
$endif

$ifdef Handle_CCP3
    If IntFlag_CCP3 = 1 Then
        GoSub _ISR_CCP3
    EndIf
$endif

$ifdef Handle_CCP4
    If IntFlag_CCP4 = 1 Then
        GoSub _ISR_CCP4
    EndIf
$endif

$ifdef Handle_CCP5
    If IntFlag_CCP5 = 1 Then
        GoSub _ISR_CCP5
    EndIf
$endif

$ifdef Handle_TMR4_Match
    If IntFlag_TMR4_Match = 1 Then
        GoSub _ISR_TMR4_Match
    EndIf
$endif

$ifdef Handle_TMR5
    If IntFlag_TMR5 = 1 Then
        GoSub _ISR_TMR5
    EndIf
$endif

$ifdef Handle_TMR6_Match
    If IntFlag_TMR6_Match = 1 Then
        GoSub _ISR_TMR6_Match
    EndIf
$endif

$endif ' 18F25K22 device

$ifdef _Managed_ISR
    Context Restore
$else
    Retfie Fast
$endif

'----------------------------------------------------------------------------
' PORTB change interrupt manager
'
$define ISR_PORTB(pParam1) '
$if pParam1 = START             '
_ISR_RB:                        '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_PORTB = 0           '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' INT0 interrupt manager
'
$define ISR_INT0(pParam1) '
$if pParam1 = START             '
_ISR_INT0:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_INT0 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' INT1 interrupt manager
'
$define ISR_INT1(pParam1) '
$if pParam1 = START             '
_ISR_INT1:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_INT1 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' INT2 interrupt manager
'
$define ISR_INT2(pParam1) '
$if pParam1 = START             '
_ISR_INT2:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_INT2 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR0 overflow interrupt manager
'
$define ISR_TMR0(pParam1) '
$if pParam1 = START             '
_ISR_TMR0:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR0 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR1 overflow interrupt manager
'
$define ISR_TMR1(pParam1) '
$if pParam1 = START             '
_ISR_TMR1:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR1 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Timer2 to PR2 match interrupt manager
'
$define ISR_TMR2_Match(pParam1) '
$if pParam1 = START             '
_ISR_TMR2_Match:                '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR2_Match = 0      '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR3 overflow interrupt manager
'
$define ISR_TMR3(pParam1) '
$if pParam1 = START             '
_ISR_TMR3:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR3 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif
'----------------------------------------------------------------------------
' UART receive interrupt manager
'
$define ISR_RX(pParam1) '
$if pParam1 = START             '
_ISR_RX:                        '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_RX = 0              '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

$define ISR_RX1(pParam1) ISR_RX(pParam1)

'----------------------------------------------------------------------------
' UART transmit interrupt manager
'
$define ISR_TX(pParam1) '
$if pParam1 = START             '
_ISR_TX:                        '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TX = 0              '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

$define ISR_TX1(pParam1) ISR_TX(pParam1)

'----------------------------------------------------------------------------
' SSP interrupt manager
'
$define ISR_SSP(pParam1) '
$if pParam1 = START             '
_ISR_SSP:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_SSP = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

$define ISR_SSP1(pParam1) ISR_SSP(pParam1)

'----------------------------------------------------------------------------
' CCP1 interrupt manager
'
$define ISR_CCP1(pParam1) '
$if pParam1 = START             '
_ISR_CCP1:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CCP1 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' CCP2 interrupt manager
'
$define ISR_CCP2(pParam1) '
$if pParam1 = START             '
_ISR_CCP2:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CCP2 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' ADC interrupt manager
'
$define ISR_ADC(pParam1) '
$if pParam1 = START             '
_ISR_ADC:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_ADC = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Comparitor 1 interrupt manager
'
$define ISR_COMP1(pParam1) '
$if pParam1 = START             '
_ISR_COMP1:                     '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_COMP1 = 0           '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Comparitor 2 interrupt manager
'
$define ISR_COMP2(pParam1) '
$if pParam1 = START             '
_ISR_COMP2:                     '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_COMP2 = 0           '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Eeprom or Flash memory write interrupt manager
'
$define ISR_FLASH(pParam1)'
$if pParam1 = START             '
_ISR_FLASH:                     '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_FLASH = 0           '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' I2C Bus_Collision interrupt manager
'
$define ISR_BUS(pParam1)'
$if pParam1 = START             '
_ISR_BUS:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_BUS = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Low Voltage interrupt manager
'
$define ISR_VOLTS(pParam1)      '
$if pParam1 = START             '
_ISR_Low_Voltage:               '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_VOLTS = 0           '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Oscillator Fail interrupt manager
'
$define ISR_OSC(pParam1) '
$if pParam1 = START             '
_ISR_OSC:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_OSC = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif
'
' For the 18F25K22 device
'
$if _device = _18F25K22
'----------------------------------------------------------------------------
' SSP2 interrupt manager
'
$define ISR_SSP2(pParam1) '
$if pParam1 = START             '
_ISR_SSP2:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_SSP2 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' MSSP2 Bus Collision interrupt manager
'
$define ISR_BUS2(pParam1)       '
$if pParam1 = START             '
_ISR_BUS2:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_BUS2 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' UART2 receive interrupt manager
'
$define ISR_RX2(pParam1) '
$if pParam1 = START             '
_ISR_RX2:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_RX2 = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' UART2 transmit interrupt manager
'
$define ISR_TX2(pParam1) '
$if pParam1 = START             '
_ISR_TX2:                       '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TX2 = 0             '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' CTMU (Charge Time Measurement Unit) interrupt manager
'
$define ISR_CTMU(pParam1) '
$if pParam1 = START             '
_ISR_CTMU:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CTMU = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR1 Gate interrupt manager
'
$define ISR_TMR1_Gate(pParam1) '
$if pParam1 = START             '
_ISR_TMR1_Gate:                 '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR1_Gate = 0       '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR3 Gate interrupt manager
'
$define ISR_TMR3_Gate(pParam1) '
$if pParam1 = START             '
_ISR_TMR3_Gate:                 '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR3_Gate = 0       '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' TMR5 Gate interrupt manager
'
$define ISR_TMR5_Gate(pParam1) '
$if pParam1 = START             '
_ISR_TMR5_Gate:                 '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR5_Gate = 0       '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' CCP3 interrupt manager
'
$define ISR_CCP3(pParam1) '
$if pParam1 = START             '
_ISR_CCP3:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CCP3 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' CCP4 interrupt manager
'
$define ISR_CCP4(pParam1) '
$if pParam1 = START             '
_ISR_CCP4:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CCP4 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' CCP5 interrupt manager
'
$define ISR_CCP5(pParam1) '
$if pParam1 = START             '
_ISR_CCP5:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_CCP5 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Timer4 to PR4 match interrupt manager
'
$define ISR_TMR4_Match(pParam1) '
$if pParam1 = START             '
_ISR_TMR4_Match:                '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR4_Match = 0      '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Timer5 overflow interrupt manager
'
$define ISR_TMR5(pParam1) '
$if pParam1 = START             '
_ISR_TMR5:                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR5 = 0            '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

'----------------------------------------------------------------------------
' Timer6 to PR6 overflow interrupt manager
'
$define ISR_TMR6_Match(pParam1) '
$if pParam1 = START             '
_ISR_TMR6_Match:                '
    $ifdef _Managed_ISR         '
        High_Int_Sub_Start      '
    $endif                      '
$elseif pParam1 = EXIT          '
    IntFlag_TMR6_Match = 0      '
    Return                      '
    $ifdef _Managed_ISR         '
        High_Int_Sub_End        '
    $endif                      '
$else                           '
    $error "Parameter must be START or EXIT" '
$endif

$endif ' 18F25K22

$endif
'----------------------------------------------------------------------------
InterruptManagerMain:

$endif

