'
' Demonstrate the use of the interrupt manager
'
' Creates two high priority interrupts that increment on Timer0 and Timer1
' Within the interrupts a value is displayed and incremented
' While in the foreground another value is displayed and incremented
'
' Note: It is not recommended to use large (slow) routines in an interrupt,
' but this program serves to demonstrate the use of managed interrupts
'
    Include "Amicus18.inc"                      ' Configure the compiler to use the Amicus18 hardware (18F25K20, 64MHz)
    
$define Handle_TMR0                             ' Handle a Timer0 overflow interrupt
$define Handle_TMR1                             ' Handle a Timer1 overflow interrupt
    
    Include "Interrupt Manager.inc"             ' Load the interrupt manager into the program
    Include "Amicus18_Timers.inc"               ' Load the Amicus18 Timer macros into the program
'
' Create some variables
'
    Dim dTimer0_HighCounter As Dword            ' Counter for the Timer0 interrupt routine
    Dim dTimer1_HighCounter As Dword            ' Counter for the Timer1 interrupt routine
    Dim dForeGroundCounter As Dword             ' Counter for the foreground routine
    Dim bSlowDown As Byte                       ' Used to slow down the Timer1 interrupt

    GoTo Main                                   ' Jump over the interrupt handlers
'--------------------------------------------------------------------
' High Priority Hardware Interrupt Handler
' Interrupt's on a Timer0 Overflow
' Display on the serial terminal and increment a value
'
ISR_TMR0(Start)
    HRSOut "Int_0: ", Dec dTimer0_HighCounter, 13       ' Display the value on the serial terminal
    Inc dTimer0_HighCounter                             ' Increment the value
ISR_TMR0(Exit)                                          ' Exit the interrupt, clearing the Timer0 flag
'--------------------------------------------------------------------
' High Priority Hardware Interrupt Handler
' Interrupt's on a Timer1 Overflow
' Display on the serial terminal and increment a value
'
ISR_TMR1(Start)
    Inc bSlowDown                                           ' Increment the Slowdown variable
    If bSlowDown = 32 Then                                  ' Have we reached a value of 32?
        bSlowDown = 0                                       ' Yes. So reset the slowdown variable
        HRSOut "Int_1: ", Dec dTimer1_HighCounter, 13       ' Display the value on the serial terminal
        Inc dTimer1_HighCounter                             ' Increment the value
    EndIf
ISR_TMR1(Exit)                                              ' Exit the interrupt, clearing the Timer1 flag
'--------------------------------------------------------------------
' Main Program Loop
' Display a value in the foreground while the interrupts work in the background
'
Main:
    dTimer0_HighCounter = 0
    dTimer1_HighCounter = 0
    dForeGroundCounter = 0
    bSlowDown = 0
'
' Configure Timer0 for:
'                       Clear TMR0L\H registers
'                       Interrupt on Timer0 overflow
'                       16-bit operation
'                       Internal clock source
'                       1:128 Prescaler
'
    OpenTimer0(TIMER_INT_ON & T0_16BIT & T0_SOURCE_INT & T0_PS_1_128)
'
' Configure Timer1 for:
'                        Clear TMR1L and TMR1H registers
'                        Interrupt on Timer1 overflow
'                        16-bit read/write mode
'                        Internal clock source
'                        1:8 Prescaler
'
    OpenTimer1(TIMER_INT_ON & T1_16BIT_RW & T1_SOURCE_INT & T1_PS_1_8)

    Int_Peripheral(Enable)                  ' Enable peripheral interrupts for Timer1 operation
    Int_Global(Enable)                      ' Enable global interrupts

    While 1 = 1                             ' Create an infinite loop
        IntFlag_TMR0 = 0                    ' Disable the Timer0 overflow interrupt while transmitting
        IntFlag_TMR1 = 0                    ' Disable the Timer1 overflow interrupt while transmitting
        HRSOut "ForeGround ", Dec dForeGroundCounter, 13 ' Display the  value on the serial terminal
        IntFlag_TMR1 = 1                    ' Re-Enable the Timer1 overflow interrupt
        IntFlag_TMR0 = 1                    ' Re-Enable the Timer0 overflow interrupt
        Inc dForeGroundCounter              ' Increment the value
        DelayMS 255
    Wend                                    ' Close the loop. i.e. do it forever

