'
' Demonstrate the use of the interrupt manager
'
' Create and handle two timer overflow interrupts
'
    Include "Amicus18.inc"                      ' Configure the compiler to use the Amicus18 hardware (18F25K20, 64MHz)
$define Handle_TMR0                             ' Handle a Timer0 overflow interrupt
$define Handle_TMR1                             ' Handle a Timer1 overflow interrupt
  
    Include "Interrupt Manager.inc"             ' Load the interrupt manager into the program
    Include "Amicus18_Timers.inc"               ' Load the Amicus18 Timer macros into the program

    GoTo Main                                   ' Jump over the interrupt handlers
'--------------------------------------------------------------------
' High Priority Hardware Interrupt Handler
' Interrupt's on a Timer0 Overflow
' Display on the serial terminal
'
ISR_TMR0(Start)
    HRSOut "Timer0\r"                           ' Display text
ISR_TMR0(Exit)                                  ' Exit the interrupt, clearing the Timer0 flag
'--------------------------------------------------------------------
' High Priority Hardware Interrupt Handler
' Interrupt's on a Timer1 Overflow
' Display on the serial terminal
'
ISR_TMR1(Start)
    HRSOut "Timer1\r"                           ' Display text
ISR_TMR1(Exit)                                  ' Exit the interrupt, clearing the Timer1 flag
'--------------------------------------------------------------------
' Main Program Loop
'
Main:
'
' Configure Timer0 for:
'                       Clear TMR0L\H registers
'                       16-bit operation
'                       Internal clock source
'                       1:128 Prescaler
'
    OpenTimer0(TIMER_INT_OFF & T0_16BIT & T0_SOURCE_INT & T0_PS_1_128)
'
' Configure Timer1 for:
'                        Clear TMR1L and TMR1H registers
'                        16-bit read/write mode
'                        Internal clock source
'                        1:8 Prescaler
'
    OpenTimer1(TIMER_INT_OFF & T1_16BIT_RW & T1_SOURCE_INT & T1_PS_1_8)

    Int_TMR0(Enable)                        ' Enable a Timer0 overflow interrupt
    Int_TMR1(Enable)                        ' Enable a Timer1 overflow interrupt
    Int_Global(Enable)                      ' Enable global interrupts

    Stop

